==> openshift-model-config-6.2.0-sources.jar: io/fabric8/openshift/api/model/config/v1/ConsoleListFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ConsoleListFluent<A extends ConsoleListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,Console item);
  public A setToItems(Integer index,Console item);
  public A addToItems(io.fabric8.openshift.api.model.config.v1.Console... items);
  public A addAllToItems(Collection<Console> items);
  public A removeFromItems(io.fabric8.openshift.api.model.config.v1.Console... items);
  public A removeAllFromItems(Collection<Console> items);
  public A removeMatchingFromItems(Predicate<ConsoleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Console> getItems();
  public List<Console> buildItems();
  public Console buildItem(Integer index);
  public Console buildFirstItem();
  public Console buildLastItem();
  public Console buildMatchingItem(Predicate<ConsoleBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ConsoleBuilder> predicate);
  public A withItems(List<Console> items);
  public A withItems(io.fabric8.openshift.api.model.config.v1.Console... items);
  public Boolean hasItems();
  public ConsoleListFluent.ItemsNested<A> addNewItem();
  public ConsoleListFluent.ItemsNested<A> addNewItemLike(Console item);
  public ConsoleListFluent.ItemsNested<A> setNewItemLike(Integer index,Console item);
  public ConsoleListFluent.ItemsNested<A> editItem(Integer index);
  public ConsoleListFluent.ItemsNested<A> editFirstItem();
  public ConsoleListFluent.ItemsNested<A> editLastItem();
  public ConsoleListFluent.ItemsNested<A> editMatchingItem(Predicate<ConsoleBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,ConsoleFluent<ConsoleListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> openshift-model-config-6.7.0-sources.jar: io/fabric8/openshift/api/model/config/v1/ConsoleListFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ConsoleListFluent<A extends ConsoleListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,Console item);
  public A setToItems(int index,Console item);
  public A addToItems(io.fabric8.openshift.api.model.config.v1.Console... items);
  public A addAllToItems(Collection<Console> items);
  public A removeFromItems(io.fabric8.openshift.api.model.config.v1.Console... items);
  public A removeAllFromItems(Collection<Console> items);
  public A removeMatchingFromItems(Predicate<ConsoleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Console> getItems();
  public List<Console> buildItems();
  public Console buildItem(int index);
  public Console buildFirstItem();
  public Console buildLastItem();
  public Console buildMatchingItem(Predicate<ConsoleBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ConsoleBuilder> predicate);
  public A withItems(List<Console> items);
  public A withItems(io.fabric8.openshift.api.model.config.v1.Console... items);
  public Boolean hasItems();
  public ConsoleListFluent.ItemsNested<A> addNewItem();
  public ConsoleListFluent.ItemsNested<A> addNewItemLike(Console item);
  public ConsoleListFluent.ItemsNested<A> setNewItemLike(int index,Console item);
  public ConsoleListFluent.ItemsNested<A> editItem(int index);
  public ConsoleListFluent.ItemsNested<A> editFirstItem();
  public ConsoleListFluent.ItemsNested<A> editLastItem();
  public ConsoleListFluent.ItemsNested<A> editMatchingItem(Predicate<ConsoleBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,ConsoleFluent<ConsoleListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
